# DP-GEN Contributing Guide
Welcome to [DP-GEN](https://github.com/deepmodeling/dpgen/tree/master/dpgen) !


## How to contribute
DP-GEN adopts the same convention as other softwares in DeepModeling Community. 
You can first refer to DeePMD-kit's
[Contributing guide](https://github.com/deepmodeling/deepmd-kit/edit/devel/CONTRIBUTING.md)
and [Developer guide](https://github.com/deepmodeling/deepmd-kit/edit/devel/doc/development/index.md).

